@@ -2,6 +2,8 @@
 import abc
 import functools
 import torch
+from collections import OrderedDict
+
 
 from ..manifold import basic_manifold
 # from autograd import grad, jacobian
@@ -18,6 +20,8 @@ class basic_manifold_torch(basic_manifold):
         self.regularize_value = regularize_value
         self.safegurad_value = safegurad_value
 
+        self._parameters = OrderedDict()
+
         
         # self.manifold_type = 'S'
         # self.backbone = 'torch'
