@@ -15,7 +15,7 @@ class oblique_torch(basic_manifold_torch):
         self.dtype = dtype
         
 
-        super().__init__('Oblique',var_shape, (*self.dim,1 ),   device= self.device ,dtype= self.dtype)
+        super().__init__('oblique',var_shape, (*self.dim,1 ),   device= self.device ,dtype= self.dtype)
 
     
 
